@@ -76,16 +76,21 @@ pub(super) fn dispatch(repo: &gix::Repository, matches: &clap::ArgMatches) -> Re
 
     let parent_branch = if let Some(committish_str) = maybe_committish_str {
         statuses.check_worktree_clean()?;
-
-        if let Ok(parent_reference) = repo.find_reference(committish_str) {
-            let parent_branchname = parent_reference
-                .name()
-                .shorten()
-                .to_str()
-                .expect("reference name is valid UTF-8");
+        if let Some(parent_reference) =
+            repo.find_reference(committish_str)
+                .ok()
+                .filter(|parent_reference| {
+                    use gix::refs::Category;
+                    matches!(
+                        parent_reference.name().category(),
+                        Some(Category::LocalBranch | Category::RemoteBranch)
+                    )
+                })
+        {
+            let parent_shortname = parent_reference.name().shorten();
             print_info_message(
                 matches,
-                &format!("Recording `{parent_branchname}` as parent branch"),
+                &format!("Recording `{parent_shortname}` as parent branch"),
             );
             Some(Branch::wrap(parent_reference))
         } else {
@@ -115,10 +120,6 @@ pub(super) fn dispatch(repo: &gix::Repository, matches: &clap::ArgMatches) -> Re
         (Rc::new(repo.head_commit()?), "HEAD")
     };
 
-    let parent_branchname = parent_branch
-        .as_ref()
-        .and_then(|branch| branch.get_branch_partial_name().ok());
-
     repo.edit_reference(gix::refs::transaction::RefEdit {
         change: gix::refs::transaction::Change::Update {
             log: gix::refs::transaction::LogChange {
@@ -148,8 +149,9 @@ pub(super) fn dispatch(repo: &gix::Repository, matches: &clap::ArgMatches) -> Re
     };
 
     if let Some(parent_branch) = parent_branch.as_ref() {
+        let parent_branchname = parent_branch.get_branch_partial_name().ok();
         super::set_stgit_parent(repo, new_branchname, parent_branchname.as_ref())?;
-        if let Some(upstream_name) = copy_upstream(parent_branch, &new_branch, repo)? {
+        if let Some(upstream_name) = set_upstream(parent_branch, &new_branch, repo)? {
             print_info_message(
                 matches,
                 &format!("Using remote `{upstream_name}` to pull parent from"),
@@ -171,38 +173,74 @@ pub(super) fn dispatch(repo: &gix::Repository, matches: &clap::ArgMatches) -> Re
     }
 }
 
-fn copy_upstream(
+fn set_upstream(
     from_branch: &Branch,
     to_branch: &Branch,
     repo: &gix::Repository,
 ) -> Result<Option<String>> {
-    let (category, from_short_name) = from_branch
+    use gix::refs::Category;
+
+    let (from_category, from_short_name) = from_branch
         .get_reference_name()
         .category_and_short_name()
-        .expect("from reference is a local branch");
-    assert!(matches!(category, gix::refs::Category::LocalBranch));
-    let (category, to_short_name) = to_branch
+        .expect("local or remote branch");
+
+    let (to_category, to_short_name) = to_branch
         .get_reference_name()
         .category_and_short_name()
         .expect("to reference is a local branch");
-    assert!(matches!(category, gix::refs::Category::LocalBranch));
-    let config = repo.config_snapshot();
-    let remote = config.string(format!("branch.{from_short_name}.remote").as_str());
-    let merge = config.string(format!("branch.{from_short_name}.merge").as_str());
-    if let (Some(remote), Some(merge)) = (remote, merge) {
-        let merge_name = gix::refs::FullName::try_from(merge.as_bstr())?;
-        let merge_short_name = merge_name.shorten().to_str_lossy();
-        let mut local_config_file = repo.local_config_file()?;
-        local_config_file.set_raw_value(
-            "branch",
-            Some(to_short_name),
-            "remote",
-            remote.as_bstr(),
-        )?;
-        local_config_file.set_raw_value("branch", Some(to_short_name), "merge", merge.as_bstr())?;
-        repo.write_local_config(local_config_file)?;
-        Ok(Some(format!("{remote}/{merge_short_name}")))
-    } else {
-        Ok(None)
+    assert!(matches!(to_category, Category::LocalBranch));
+
+    match from_category {
+        Category::LocalBranch => {
+            let config = repo.config_snapshot();
+            let remote = config.string(format!("branch.{from_short_name}.remote").as_str());
+            let merge = config.string(format!("branch.{from_short_name}.merge").as_str());
+
+            if let (Some(remote), Some(merge)) = (remote, merge) {
+                let merge_name = gix::refs::FullName::try_from(merge.as_bstr())?;
+                let merge_short_name = merge_name.shorten();
+                let mut local_config_file = repo.local_config_file()?;
+                local_config_file.set_raw_value(
+                    "branch",
+                    Some(to_short_name),
+                    "remote",
+                    remote.as_bstr(),
+                )?;
+                local_config_file.set_raw_value(
+                    "branch",
+                    Some(to_short_name),
+                    "merge",
+                    merge.as_bstr(),
+                )?;
+                repo.write_local_config(local_config_file)?;
+                Ok(Some(format!("{remote}/{merge_short_name}")))
+            } else {
+                Ok(None)
+            }
+        }
+
+        Category::RemoteBranch => {
+            let mut local_config_file = repo.local_config_file()?;
+            let (remote_name, remote_branch_name) = from_short_name
+                .split_once_str(b"/")
+                .expect("remote branch short name has form <remote>/<branch>");
+            local_config_file.set_raw_value(
+                "branch",
+                Some(to_short_name),
+                "remote",
+                remote_name,
+            )?;
+            local_config_file.set_raw_value(
+                "branch",
+                Some(to_short_name),
+                "merge",
+                remote_branch_name,
+            )?;
+            repo.write_local_config(local_config_file)?;
+            Ok(Some(from_short_name.to_string()))
+        }
+
+        _ => panic!("from branch must be LocalBranch or RemoteBranch"),
     }
 }
