@@ -11,10 +11,9 @@ use clap::{Arg, ArgMatches};
 use crate::{
     argset,
     color::get_color_stdout,
-    patchedit::{self, call_editor},
-    patchname::PatchName,
+    ext::RepositoryExtended,
+    patch::{patchedit, PatchName, SingleRevisionSpec},
     print_info_message,
-    revspec::parse_stgit_revision,
     stack::{InitializationPolicy, Stack, StackAccess, StackStateAccess},
     stupid::Stupid,
 };
@@ -50,7 +49,7 @@ fn make() -> clap::Command {
         .arg(
             Arg::new("committish")
                 .help("New base commit for the stack")
-                .value_parser(clap::builder::NonEmptyStringValueParser::new())
+                .value_parser(clap::value_parser!(SingleRevisionSpec))
                 .required_unless_present("interactive"),
         )
         .arg(
@@ -93,24 +92,23 @@ fn make() -> clap::Command {
 }
 
 fn run(matches: &ArgMatches) -> Result<()> {
-    let repo = git2::Repository::open_from_env()?;
-    let stack = Stack::from_branch(&repo, None, InitializationPolicy::RequireInitialized)?;
-    let config = repo.config()?;
+    let repo = gix::Repository::open()?;
+    let stack = Stack::current(&repo, InitializationPolicy::RequireInitialized)?;
+    let config = repo.config_snapshot();
     let stupid = repo.stupid();
     let branch_name = stack.get_branch_name().to_string();
     let allow_push_conflicts = argset::resolve_allow_push_conflicts(&config, matches);
     let committer_date_is_author_date = matches.get_flag("committer-date-is-author-date");
 
-    let target_commit = if let Some(committish) = argset::get_one_str(matches, "committish") {
-        parse_stgit_revision(&repo, Some(committish), None)?.peel_to_commit()?
-    } else {
-        stack.base().clone()
-    };
+    let target_commit =
+        if let Some(committish) = matches.get_one::<SingleRevisionSpec>("committish") {
+            committish.resolve(&repo, Some(&stack))?.commit
+        } else {
+            stack.base().clone()
+        };
 
     if stack.is_protected(&config) {
-        return Err(anyhow!(
-            "This branch is protected. Rebase is not permitted."
-        ));
+        return Err(anyhow!("this branch is protected; rebase is not permitted"));
     }
 
     stack.check_head_top_mismatch()?;
@@ -118,12 +116,35 @@ fn run(matches: &ArgMatches) -> Result<()> {
 
     let autostash = if matches.get_flag("autostash") {
         true
-    } else if let Ok(autostash) = config.get_bool("branch.{branch_name}.stgit.autostash") {
-        autostash
-    } else if let Ok(autostash) = config.get_bool("stgit.autostash") {
-        autostash
     } else {
-        false
+        config
+            .plumbing()
+            .boolean(
+                "branch",
+                Some(format!("{branch_name}.stgit").as_str().into()),
+                "autostash",
+            )
+            .transpose()
+            .unwrap_or_else(|e| {
+                crate::print_warning_message(
+                    matches,
+                    &format!("Invalid config value `branch.{branch_name}.stgit.autostash`: {e}"),
+                );
+                Some(false)
+            })
+            .or_else(|| {
+                config
+                    .try_boolean("stgit.autostash")
+                    .transpose()
+                    .unwrap_or_else(|e| {
+                        crate::print_warning_message(
+                            matches,
+                            &format!("Invalid config value `stgit.autostash`: {e}"),
+                        );
+                        Some(false)
+                    })
+            })
+            .unwrap_or(false)
     };
 
     let using_stash = if autostash && clean_result.is_err() {
@@ -148,13 +169,19 @@ fn run(matches: &ArgMatches) -> Result<()> {
         .execute("rebase (pop)")?;
 
     let rebase_cmd = config
-        .get_string(&format!("branch.{branch_name}.stgit.rebasecmd"))
-        .or_else(|_| config.get_string("stgit.rebasecmd"))
-        .unwrap_or_else(|_| "git reset --hard".to_string());
+        .plumbing()
+        .string(
+            "branch",
+            Some(format!("{branch_name}.stgit").as_str().into()),
+            "rebasecmd",
+        )
+        .or_else(|| config.string("stgit.rebasecmd"))
+        .and_then(|bs| bs.to_str().map(str::to_string).ok())
+        .unwrap_or_else(|| "git reset --hard".to_string());
     print_info_message(matches, &format!("Rebasing to `{}`", target_commit.id()));
-    stupid.user_rebase(&rebase_cmd, target_commit.id())?;
+    stupid.user_rebase(&rebase_cmd, target_commit.id)?;
 
-    let stack = Stack::from_branch(&repo, None, InitializationPolicy::RequireInitialized)?;
+    let stack = Stack::current(&repo, InitializationPolicy::RequireInitialized)?;
     let stack = if stack.is_head_top() {
         stack
     } else {
@@ -189,10 +216,7 @@ fn run(matches: &ArgMatches) -> Result<()> {
         if stupid.stash_pop()? {
             Ok(())
         } else {
-            Err(
-                crate::stack::Error::CausedConflicts("Stash pop resulted in conflicts".to_string())
-                    .into(),
-            )
+            Err(super::Error::CausedConflicts("stash pop resulted in conflicts".to_string()).into())
         }
     } else {
         Ok(())
@@ -234,8 +258,8 @@ enum Action {
 
 fn interactive_pushback(
     stack: Stack,
-    repo: &git2::Repository,
-    config: &git2::Config,
+    repo: &gix::Repository,
+    config: &gix::config::Snapshot,
     matches: &ArgMatches,
     previously_applied: &[PatchName],
     allow_push_conflicts: bool,
@@ -253,7 +277,7 @@ fn interactive_pushback(
         make_instructions_template(&stack, previously_applied),
     )?;
 
-    let buf = call_editor(filename, config)?;
+    let buf = patchedit::call_editor(filename, config)?;
     let buf = buf
         .to_str()
         .map_err(|_| anyhow!("`{filename}` is not valid UTF-8"))?;
@@ -385,7 +409,7 @@ fn interactive_pushback(
                     patchnames
                 } else {
                     return Err(anyhow!(
-                        "Cannot {action_str} `{patchname}`: no preceding patch"
+                        "cannot {action_str} `{patchname}`: no preceding patch"
                     ));
                 };
 
@@ -399,8 +423,8 @@ fn interactive_pushback(
                     }
                     Action::Fixup => {
                         let commit = stack.get_patch_commit(target_patchname);
-                        let message = commit.message_raw().ok_or_else(|| {
-                            anyhow!("Fixup target patch `{target_patchname}` has non-UTF-8 message")
+                        let message = commit.message_raw()?.to_str().map_err(|_| {
+                            anyhow!("fixup target patch `{target_patchname}` has non-UTF-8 message")
                         })?;
                         dummy_squash_command.try_get_matches_from([
                             "dummy-squash",
@@ -418,7 +442,6 @@ fn interactive_pushback(
                     .transact(|trans| {
                         let new_patchname = super::squash::squash(
                             trans,
-                            config,
                             &squash_matches,
                             &squash_patchnames,
                             Some(target_patchname),
@@ -471,7 +494,10 @@ fn make_instructions_template(stack: &Stack, previously_applied: &[PatchName]) -
             found_apply_boundary = true;
         }
         let commit = stack.get_patch_commit(patchname);
-        let subject = commit.summary().unwrap_or_default();
+        let subject = commit
+            .message()
+            .map(|message_ref| message_ref.title.to_str_lossy())
+            .unwrap_or_default();
         writeln!(template, "keep {patchname:name_width$} # {subject}").unwrap();
     }
     if !found_apply_boundary {
@@ -492,7 +518,7 @@ fn parse_instructions(buf: &str) -> Result<Vec<Instruction>> {
             if line == INTERACTIVE_APPLY_LINE {
                 apply = false;
             } else {
-                return Err(anyhow!("Bad APPLY_LINE: `{line}`"));
+                return Err(anyhow!("bad APPLY_LINE: `{line}`"));
             }
         }
 
@@ -517,7 +543,7 @@ fn parse_instructions(buf: &str) -> Result<Vec<Instruction>> {
                 "f" | "fix" | "fixup" => Action::Fixup,
                 "h" | "hide" => Action::Hide,
                 "d" | "delete" => Action::Delete,
-                _ => return Err(anyhow!("Unknown instruction action `{action_str}`")),
+                _ => return Err(anyhow!("unknown instruction action `{action_str}`")),
             };
 
             let patchname = PatchName::from_str(patchname_str)?;
@@ -528,7 +554,7 @@ fn parse_instructions(buf: &str) -> Result<Vec<Instruction>> {
                 apply,
             });
         } else {
-            return Err(anyhow!("Bad instruction line: `{line}`"));
+            return Err(anyhow!("bad instruction line: `{line}`"));
         }
     }
     Ok(instructions)
@@ -539,9 +565,9 @@ fn validate_instructions(stack: &Stack, instructions: &[Instruction]) -> Result<
     for instruction in instructions {
         let patchname = &instruction.patchname;
         if !stack.has_patch(patchname) {
-            return Err(anyhow!("Unknown patch name `{patchname}`"));
+            return Err(anyhow!("unknown patch name `{patchname}`"));
         } else if seen_patchnames.contains(&patchname) {
-            return Err(anyhow!("Duplicated patch name `{patchname}`"));
+            return Err(anyhow!("duplicated patch name `{patchname}`"));
         } else {
             seen_patchnames.push(patchname);
         }
