@@ -51,6 +51,7 @@ const CONFLICT_ERROR: i32 = 3;
 /// cost of instantiating [`clap::Command`] instances for every StGit subcommand.
 fn get_base_command(color_choice: Option<termcolor::ColorChoice>) -> clap::Command {
     let mut command = clap::Command::new("stg")
+        .styles(cmd::STYLES)
         .about("Maintain a stack of patches on top of a Git branch.")
         .override_usage(cmd::make_usage(
             "stg",
@@ -394,8 +395,8 @@ fn execute_shell_alias(
     if let Some(repo) = repo {
         if let Some(work_dir) = repo.work_dir() {
             command.current_dir(work_dir);
-            if let Some(Ok(prefix)) = repo.prefix() {
-                let mut prefix = prefix.into_os_string();
+            if let Ok(Some(prefix)) = repo.prefix() {
+                let mut prefix = prefix.as_os_str().to_owned();
                 if !prefix.is_empty() {
                     prefix.push("/");
                 }
